@@ -1,3 +1,4 @@
+from __future__ import annotations
 import re
 import typing as T
 from pathlib import Path
@@ -8,6 +9,8 @@ import logging
 
 import aiohttp
 
+from . import files
+
 # tuples, not lists
 
 EXC = (
@@ -19,16 +22,17 @@ TIMEOUT = 10
 
 
 async def check_urls(
-    flist: T.Iterable[Path],
+    path: Path,
     regex: str,
     ext: str,
-    hdr: T.Dict[str, str] = None,
+    hdr: dict[str, str] = None,
     method: str = "get",
-) -> T.List[T.Tuple[str, str, T.Any]]:
+    recurse: bool = False,
+) -> list[tuple[str, str, T.Any]]:
 
     glob = re.compile(regex)
 
-    tasks = [check_url(fn, glob, ext, hdr, method=method) for fn in flist]
+    tasks = [check_url(fn, glob, ext, hdr, method=method) for fn in files.get(path, ext, recurse)]
 
     warnings.simplefilter("ignore")
 
@@ -36,16 +40,20 @@ async def check_urls(
 
     warnings.resetwarnings()
 
+    # this is per aiohttp manual, when using HTTPS SSL sites, just before closing
+    # the event loop, do a 250ms sleep (not for each site)
+    await asyncio.sleep(0.250)
+
     return list(itertools.chain(*urls))  # flatten list of lists
 
 
 async def check_url(
-    fn: Path, glob, ext: str, hdr: T.Dict[str, str] = None, *, method: str = "get"
-) -> T.List[T.Tuple[str, str, T.Any]]:
+    fn: Path, glob, ext: str, hdr: dict[str, str] = None, *, method: str = "get"
+) -> list[tuple[str, str, T.Any]]:
 
     urls = glob.findall(fn.read_text(errors="ignore"))
     logging.debug(fn.name, " ".join(urls))
-    bad = []  # type: T.List[T.Tuple[str, str, T.Any]]
+    bad: list[tuple[str, str, T.Any]] = []
 
     timeout = aiohttp.ClientTimeout(total=TIMEOUT)
 
