@@ -1,3 +1,4 @@
+from __future__ import annotations
 import requests
 import re
 import typing as T
@@ -6,6 +7,8 @@ import warnings
 import urllib3
 import logging
 
+from . import files
+
 TIMEOUT = 10
 RETRYCODES = (400, 404, 405, 503)
 # multiple exceptions must be tuples, not lists in general
@@ -18,14 +21,15 @@ synchronous routines
 
 
 def check_urls(
-    flist: T.Iterable[Path],
+    path: Path,
     regex: str,
     ext: str = ".md",
-    hdr: T.Dict[str, str] = None,
+    hdr: dict[str, str] = None,
     verifycert: bool = False,
-) -> T.List[T.Tuple[str, str, T.Any]]:
+    recurse: bool = False,
+) -> list[tuple[str, str, T.Any]]:
 
-    bads: T.List[T.Tuple[str, str, T.Any]] = []
+    bads: list[tuple[str, str, T.Any]] = []
 
     glob = re.compile(regex)
 
@@ -36,7 +40,7 @@ def check_urls(
             sess.headers.update(hdr)
             sess.max_redirects = 5
         # %% loop
-        for fn in flist:
+        for fn in files.get(path, ext, recurse):
             for bad in check_url(fn, glob, ext, sess, hdr, verifycert):
                 print("\n", bad)
                 bads.append(bad)
@@ -47,8 +51,8 @@ def check_urls(
 
 
 def check_url(
-    fn: Path, glob, ext: str, sess, hdr: T.Dict[str, str] = None, verifycert: bool = False
-) -> T.Iterable[T.Tuple[str, str, T.Any]]:
+    fn: Path, glob, ext: str, sess, hdr: dict[str, str] = None, verifycert: bool = False
+) -> T.Iterable[tuple[str, str, T.Any]]:
 
     urls = glob.findall(fn.read_text(errors="ignore"))
 
@@ -78,7 +82,7 @@ def check_url(
             logging.info(f"OK: {url:80s}")
 
 
-def retry(url: str, hdr: T.Dict[str, str] = None, verifycert: bool = False) -> bool:
+def retry(url: str, hdr: dict[str, str] = None, verifycert: bool = False) -> bool:
     ok = False
 
     try:
