@@ -11,26 +11,28 @@ def test_local():
     assert len(urls) == 2
 
 
-@pytest.mark.parametrize("mode", ["sync", "coro"])
-def test_mod(mode):
+@pytest.mark.parametrize("use_async", [True, False])
+def test_mod(use_async):
 
-    if mode == "sync":
+    if not use_async:
         pytest.importorskip("requests", reason="Synchronous requires requests")
 
     with importlib.resources.path("linkcheckmd.tests", "badlink.md") as file:
-        urls = lc.check_remotes(file, domain="github.invalid", ext=".md", mode=mode)
+        urls = lc.check_remotes(file, domain="github.invalid", ext=".md", use_async=use_async)
 
     assert len(urls) == 2
 
 
-@pytest.mark.parametrize("mode", ["sync", "coro"])
-def test_script(mode):
+@pytest.mark.parametrize("use_async", [True, False])
+def test_script(use_async):
 
-    if mode == "sync":
+    args = []
+    if not use_async:
         pytest.importorskip("requests", reason="Synchronous requires requests")
+        args.append("--sync")
 
     with importlib.resources.path("linkcheckmd.tests", "badlink.md") as file:
         ret = subprocess.check_output(
-            ["linkcheckMarkdown", str(file), "github.invalid", "--mode", mode], text=True
+            ["linkcheckMarkdown", str(file), "github.invalid"] + args, text=True
         )
     assert "github.invalid" in ret
